glossaryExempt property
Skip the glossary-enforcement check on this key. Use when the source string uses a glossary term in a non-literal sense.
Implementation
final bool glossaryExempt;
Skip the glossary-enforcement check on this key. Use when the source string uses a glossary term in a non-literal sense.
final bool glossaryExempt;