ArbPlaceholder class

Constructors

ArbPlaceholder({String? type, String? format, Map<String, Object?> extras = const {}})

Properties

extras Map<String, Object?>
Preserved unknown fields.
final
format String?
Format hint (e.g. compactLong for numbers, yMMMd for dates).
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
String, int, double, DateTime — per ARB convention.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited