hasPluralOrSelect static method

bool hasPluralOrSelect(
  1. String message
)

True if message contains any plural, select, or selectordinal expression at any nesting depth — i.e. anything flat-json would collapse. Used to count lossy events for the sync hint.

Implementation

static bool hasPluralOrSelect(String message) {
  var found = false;
  _walk(message, (expr) {
    if (expr.type == 'plural' ||
        expr.type == 'select' ||
        expr.type == 'selectordinal') {
      found = true;
    }
  });
  return found;
}