BundleLocale class

One locale's file within a bundle.

Constructors

BundleLocale({required String locale, required String file, required String content, required String sha256, required int keys})

Properties

content String
final
file String
final
hashCode int
The hash code for this object.
no setterinherited
keys int
final
locale String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sha256 String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited