PulledBundle class

Constructors

PulledBundle({required String version, required String format, required List<PulledLocale> locales})

Properties

format String
final
hashCode int
The hash code for this object.
no setterinherited
locales List<PulledLocale>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited