result property
Issues that survived suppression (what the report should show and what the exit code is computed from).
Implementation
final CheckResult result;
Issues that survived suppression (what the report should show and what the exit code is computed from).
final CheckResult result;