FixReport class

Result of dialect check --fix: which files were rewritten and the total count, for terminal output.

Constructors

FixReport({required List<String> changedFiles})

Properties

changedFiles List<String>
Files that were re-written because their on-disk form differed from canonical. Paths match ArbFile.sourcePath.
final
count int
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited