file property
Absolute or repo-relative path to the file containing the issue.
null only when the rule is reporting a project-wide condition.
Implementation
final String? file;
Absolute or repo-relative path to the file containing the issue.
null only when the rule is reporting a project-wide condition.
final String? file;