message property
One-line problem description. Should be specific enough that a reader can act on it without reading the surrounding context.
Implementation
final String message;
One-line problem description. Should be specific enough that a reader can act on it without reading the surrounding context.
final String message;