ruleName property
Stable identifier the report uses to group issues, and that users
will reference when filing bugs. Snake_case, e.g. missing_keys,
plural_categories.
Implementation
final String ruleName;
Stable identifier the report uses to group issues, and that users
will reference when filing bugs. Snake_case, e.g. missing_keys,
plural_categories.
final String ruleName;