checks/semantic/stale_translation library

Classes

StaleTranslationRule
Flags translations whose stored @key.source_hash no longer matches the current English source — i.e. the source changed after the translation was written, so the translation is potentially out of date.