WidthBudgetInfo class

The budget resolved for a source key, for callers outside the rule (e.g. dialect translate inlining the constraint into its plan).

Constructors

WidthBudgetInfo({required int maxChars, required int sourceChars, required String label})

Properties

hashCode int
The hash code for this object.
no setterinherited
label String
Budget source, e.g. slot \button``.
final
maxChars int
Effective character cap.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceChars int
Literal length of the source string (the ratio base).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited