SelectionFailure class

A selection that could not be resolved: code is the exit code the command should return, lines the message to print to stderr.

Implemented types

Constructors

SelectionFailure(int code, List<String> lines)

Properties

code int
final
hashCode int
The hash code for this object.
no setterinherited
lines List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited