project/output_scan library

Classes

OutputScan
Compares the generated outputs on disk against the canonical source, and reports orphan keys: keys that exist in a generated file but not in dialect/source.