AckRecord class

One acknowledgement record. acknowledged is the source/translation fingerprint at ack-time (sha256-16). The rest is informational.

Constructors

AckRecord({required String acknowledged, String? acknowledgedAt, String? note, String? acknowledgedBy, Map<String, Object?>? extras})

Properties

acknowledged String
final
acknowledgedAt String?
final
acknowledgedBy String?
final
extras Map<String, Object?>
Unknown fields inside the record, preserved verbatim.
final
hashCode int
The hash code for this object.
no setterinherited
note String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, Object?> json) AckRecord