Bundle class
An immutable, content-addressed bundle ready to upload.
Constructors
Properties
- channelHeadJson → String
-
The channel head (
<prefix>/manifest.json) pointing at this version.no setter - createdAt → String
-
final
- format → String
-
final
- generator → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
locales
→ List<
BundleLocale> -
final
- manifestJson → String
-
The immutable bundle manifest (
b/<version>/manifest.json).no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceLocale → String
-
final
- version → String
-
final
- versionDir → String
-
Prefix-relative directory holding the immutable objects.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited