BundleWriteResult class
Constructors
-
BundleWriteResult({required bool alreadyPublished, required List<
String> filesWritten, required bool headUpdated})
Properties
- alreadyPublished → bool
-
True when the version dir already existed — no immutable objects were
(re-)written.
final
-
filesWritten
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headUpdated → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited