checks/semantic/plural_shape library
Classes
- PluralShapeRule
-
A count is interpolated into a sentence that has only one grammatical
shape, so some value of that count reads wrong:
"{count} people"renders "1 people".
"{count} people"
renders "1 people".